Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3426)

Unified Diff: base/nss_util.cc

Issue 3845002: Convert LOG(INFO) to VLOG(1) - base/. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/metrics/histogram.cc ('k') | base/observer_list_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/nss_util.cc
===================================================================
--- base/nss_util.cc (revision 62784)
+++ base/nss_util.cc (working copy)
@@ -230,10 +230,10 @@
SECStatus status = NSS_Shutdown();
if (status != SECSuccess) {
- // We LOG(INFO) because this failure is relatively harmless
- // (leaking, but we're shutting down anyway).
- LOG(INFO) << "NSS_Shutdown failed; see "
- "http://code.google.com/p/chromium/issues/detail?id=4609";
+ // We VLOG(1) because this failure is relatively harmless (leaking, but
+ // we're shutting down anyway).
+ VLOG(1) << "NSS_Shutdown failed; see "
+ "http://code.google.com/p/chromium/issues/detail?id=4609";
}
}
« no previous file with comments | « base/metrics/histogram.cc ('k') | base/observer_list_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698